@@ -1,7 +1,5 @@
-#  Copyright (c) 2020 zfit
+#  Copyright (c) 2021 zfit
 
-# noinspection PyUnresolvedReferences
-from zfit.core.testing import setup_function, teardown_function, tester
 
 from zfit.util.temporary import TemporarilySet
 
